# Zhipu AI API

[![GitHub][github_badge]][github_link] [![PyPI][pypi_badge]][pypi_link]

Python SDK for the Zhipu AI API



## Installation

```bash
pip install zhipuai-api
```



## Quickstart

```python
import zhipuai
```



## License

Zhipu AI API has a BSD-3-Clause license, as found in the [LICENSE](https://github.com/imyizhang/zhipuai-api/blob/main/LICENSE) file.



## Contributing



## Changelog



[github_badge]: https://badgen.net/badge/icon/GitHub?icon=github&color=black&label
[github_link]: https://github.com/imyizhang/zhipuai-api



[pypi_badge]: https://badgen.net/pypi/v/zhipuai-api?icon=pypi&color=black&label
[pypi_link]: https://www.pypi.org/project/zhipuai-api